#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_DIVROUND_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_DIVROUND_HPP_INCLUDED

#include <boost/simd/arithmetic/include/functions/divround.hpp>

#endif
